@@ -1,19 +1,15 @@
 #!/bin/bash
-# Copyright 2015-2020 Rumma & Ko Ltd
+# Copyright 2015-2021 Rumma & Ko Ltd
 # License: BSD (see file COPYING for details)
 #
 # Make a snapshot of a Lino database.
-# This is meant as template for a script to be adapted to your system.
-# This is not meant to be used as is.
 #
 
 set -e  # exit on error
 
-# YOU MUST edit the following lines:
 # WARNING: all files older than 60 days in ARCHDIR will be deleted
 # without confirmation
 
-
 PROJECT_DIR={{project_dir}}
 ARCH_DIR={{backups_base}}/{{prjname}}
 ENVDIR=$PROJECT_DIR/{{env_link}}
@@ -74,18 +70,22 @@ fi
 echo "Writing $ZIPFILE..."
 zip -r $ZIPFILE $SNAPSHOTDIR
 
-if [ -f fixtures ] ; then
+if [ -d fixtures ] ; then
   zip -r $ZIPFILE fixtures
 fi
 
-if [ -f media/webdav ] ; then
+if [ -d media/webdav ] ; then
 zip -r $ZIPFILE media/webdav
 fi
 
-if [ -f media/beid ] ; then
+if [ -d media/beid ] ; then
 zip -r $ZIPFILE media/beid
 fi
 
+if [ -d media/uploads ] ; then
+zip -r $ZIPFILE media/uploads
+fi
+
 zip $ZIPFILE *.py *.sh
 
 # delete all files older than 60 days in ARCHDIR:
